@@ -14,6 +14,7 @@ from sync_pre_commit_lock.pdm_plugin import (
     PDMPrinter,
     PDMSetupPreCommitHooks,
 )
+from sync_pre_commit_lock.pre_commit_config import PreCommitRepo
 
 # Create the mock objects
 
@@ -36,8 +37,9 @@ action_mock = mock.create_autospec(PDMSetupPreCommitHooks, instance=True)
 
 def test_on_pdm_install_setup_pre_commit_auto_install_disabled(project: mock.MagicMock) -> None:
     config_mock.automatically_install_hooks = False
-    with mock.patch("sync_pre_commit_lock.pdm_plugin.PDMPrinter", return_value=printer_mock), mock.patch(
-        "sync_pre_commit_lock.pdm_plugin.load_config", return_value=config_mock
+    with (
+        mock.patch("sync_pre_commit_lock.pdm_plugin.PDMPrinter", return_value=printer_mock),
+        mock.patch("sync_pre_commit_lock.pdm_plugin.load_config", return_value=config_mock),
     ):
         from sync_pre_commit_lock.pdm_plugin import on_pdm_install_setup_pre_commit
 
@@ -49,8 +51,9 @@ def test_on_pdm_install_setup_pre_commit_no_config_file(tmp_path: Path, project:
     config_mock.automatically_install_hooks = True
     config_mock.pre_commit_config_file = SyncPreCommitLockConfig.pre_commit_config_file
     project.root = tmp_path
-    with mock.patch("sync_pre_commit_lock.pdm_plugin.PDMPrinter", return_value=printer_mock), mock.patch(
-        "sync_pre_commit_lock.pdm_plugin.load_config", return_value=config_mock
+    with (
+        mock.patch("sync_pre_commit_lock.pdm_plugin.PDMPrinter", return_value=printer_mock),
+        mock.patch("sync_pre_commit_lock.pdm_plugin.load_config", return_value=config_mock),
     ):
         from sync_pre_commit_lock.pdm_plugin import on_pdm_install_setup_pre_commit
 
@@ -64,11 +67,30 @@ def test_on_pdm_install_setup_pre_commit_success(project: Project) -> None:
     project.root = (
         Path(__file__).parent.parent / "fixtures" / "poetry_project"
     )  # Assuming config file exists at this path
-    with mock.patch("sync_pre_commit_lock.pdm_plugin.load_config", return_value=config_mock), mock.patch(
-        "sync_pre_commit_lock.pdm_plugin.PDMSetupPreCommitHooks", return_value=action_mock
+    with (
+        mock.patch("sync_pre_commit_lock.pdm_plugin.load_config", return_value=config_mock),
+        mock.patch("sync_pre_commit_lock.pdm_plugin.PDMSetupPreCommitHooks", return_value=action_mock),
     ):
         from sync_pre_commit_lock.pdm_plugin import on_pdm_install_setup_pre_commit
 
         on_pdm_install_setup_pre_commit(project, hooks=hooks_mock, candidates=candidates_mock, dry_run=False)
 
     action_mock.execute.assert_called_once()
+
+
+def test_pdm_printer_list_success(capsys: pytest.CaptureFixture[str]) -> None:
+    from sync_pre_commit_lock.pdm_plugin import PDMPrinter
+
+    printer = PDMPrinter(UI())
+
+    printer.list_updated_packages(
+        {
+            "package1": (
+                PreCommitRepo(repo="https://repo1.local/test", rev="rev1"),
+                "rev2",
+            )
+        }
+    )
+    captured = capsys.readouterr()
+
+    assert "[sync-pre-commit-lock]  ✔ https://repo1.local/test   rev1 -> rev2" in captured.out
